@@ -54,6 +54,8 @@ class PhysioSignal(object):
     --------
     label : str
         physiological recording label (e.g., 'cardiac', 'respiratory', 'pulse', etc.)
+    uuid : str or None
+        Universally unique identifier (for the run which the signal comes from)
     units : str
     samples_per_second : number
     sampling_times : list of numbers
@@ -76,6 +78,7 @@ class PhysioSignal(object):
     def __init__(
             self,
             label=None,
+            uuid=None,
             units="",
             samples_per_second=None,
             sampling_times=[],
@@ -84,6 +87,7 @@ class PhysioSignal(object):
             signal=[]
             ):
         self.label = label
+        self.uuid = uuid
         self.units = units
         self.samples_per_second = samples_per_second
         self.sampling_times = sampling_times
@@ -92,6 +96,12 @@ class PhysioSignal(object):
         self.signal = signal
         self.samples_count = len( signal ) if signal is not [] else None
 
+    def __eq__(self, other):
+        if isinstance(other, self.__class__):
+            return self.__dict__ == other.__dict__
+        else:
+            return False
+
     def t_start( self ):
         """
         Computes the BIDS t_start (offset between the beginning of the neural signal and the beginning
@@ -200,12 +210,28 @@ class PhysioData(object):
         self.signals = signals if signals is not None else []
         self.bidsPrefix = bidsPrefix
 
+    def __eq__(self, other):
+        if isinstance(other, self.__class__):
+            return self.signals == other.signals
+        else:
+            return False
+
     def labels(self):
         """
         Returns a list with the labels of all the object signals
         """
         return [ item.label for item in self.signals ]
 
+    def get_trigger_physiosignal(self):
+        """
+        Returns the Physiosignal for the trigger
+        """
+        # list all the signal labels:
+        signal_labels = [l.lower() for l in self.labels()]
+
+        # physiosignal object corresponding to the trigger:
+        return self.signals[signal_labels.index('trigger')]
+
     def append_signal(self, signal):
         """
         Appends a new signal to the signals list
@@ -349,16 +375,15 @@ class PhysioData(object):
 
     def digitize_trigger(self, ignore_values=None):
         """
-        Finds the high and low states of a trigger channel and returns the timing of the received triggers.
-        It finds the first physiosignal labeled 'trigger' in the object and returns the times for which the trigger signal is high (a value of 1 means high, a value of 0 means low).
+        Finds the high and low states of a trigger channel and converts them
+        to ones (high) and zeros (low).
+
+        Return:
+        ------
         """
-        
-        # list all the signal labels:
-        signal_labels = [l.lower() for l in self.labels()]
-        
-        # physiosignal object corresponding to the trigger:
-        trig_physiosignal = self.signals[ signal_labels.index('trigger') ]
-        
+
+        trig_physiosignal = self.get_trigger_physiosignal()
+
         # make sure we have the timing of the trigger samples; otherwise, calculate:
         if len(trig_physiosignal.sampling_times) == 0:
             try:
@@ -366,33 +391,41 @@ class PhysioData(object):
             except Exception as e:
                 print(e)
                 return None
-        
+
         # check if we have any ignore_values, and if we do set them to NaN
         if ignore_values:
             for i in ignore_values:
                 trig_physiosignal.signal[trig_physiosignal.signal == i] = np.nan
-        
-        #make a histogram of trigger values with 10 bins between the min and max values
+
+        # make a histogram of trigger values with 10 bins between the min and
+        # max values
         tmp = np.array(trig_physiosignal.signal)
-        counts, bin_edges = np.histogram(tmp[~np.isnan(tmp)], bins=10, range=[min(trig_physiosignal.signal), max(trig_physiosignal.signal)])
-        
-        # find the middle values of the two bins with the most counts, we consider these two bins to contain the low a and high trigger values
+        counts, bin_edges = np.histogram(
+            tmp[~np.isnan(tmp)],
+            bins=10,
+            range=[min(trig_physiosignal.signal), max(trig_physiosignal.signal)]
+        )
+
+        # find the middle values of the two bins with the most counts, we
+        # consider these two bins to contain the low a and high trigger values
         first_bin = bin_edges[np.argmax(counts)] + (bin_edges[1]-bin_edges[0])/2
         counts[np.argmax(counts)]=0
         second_bin = bin_edges[np.argmax(counts)] + (bin_edges[1]-bin_edges[0])/2
-        
-        # define the cuttoff threshold as the mean value between the low and high values (the middle of the corresponding bins), and convert the high states to 1s and the low states to 0s
-        threshold=(first_bin + second_bin)/2
-        
-        #digitize
+
+        # define the cuttoff threshold as the mean value between the low and
+        # high values (the middle of the corresponding bins), and convert the
+        # high states to 1s and the low states to 0s
+        threshold = (first_bin + second_bin)/2
+
+        # digitize
         tmp_signal = tmp
         tmp_signal[tmp<threshold] = 0
         tmp_signal[tmp>threshold] = 1
         tmp_signal[np.isnan(tmp)] = 0
-        
-        #assign the digitized trigger signal back to the physiosignal object
+
+        # assign the digitized trigger signal back to the physiosignal object
         trig_physiosignal.signal = tmp_signal.tolist()
-        self.signals[ signal_labels.index('trigger') ] = trig_physiosignal
+        self.signals[ self.labels().index('trigger') ] = trig_physiosignal
 
     def get_trigger_timing(self):
         """
@@ -401,11 +434,7 @@ class PhysioData(object):
         the times for which the trigger signal is 1
         """
 
-        # list all the signal labels:
-        signal_labels = [l.lower() for l in self.labels()]
-
-        # PhysioSignal object corresponding to the trigger:
-        trig_physiosignal = self.signals[ signal_labels.index('trigger') ]
+        trig_physiosignal = self.get_trigger_physiosignal()
 
         # make sure we have the timing of the trigger samples; otherwise, calculate:
         if len(trig_physiosignal.sampling_times) == 0:
@@ -451,9 +480,6 @@ class PhysioData(object):
             if not self.bidsPrefix:
                 raise Exception('fileName was not a known provided')
 
-        # list all the signal labels:
-        signal_labels = [l.lower() for l in self.labels()]
-
         # Sanity check: make sure we have a "trigger" signal
         if 'trigger' not in self.labels():
             print("We cannot save with trigger because we found no trigger.")
@@ -462,7 +488,7 @@ class PhysioData(object):
 
         # From now on, we do have a trigger
         # PhysioSignal object corresponding to the trigger:
-        trig_physiosignal = self.signals[ signal_labels.index('trigger') ]
+        trig_physiosignal = self.get_trigger_physiosignal()
         t_trig = self.get_trigger_timing()
 
         # find the unique pairs of sampling rate and t_start (and indices),
