@@ -415,6 +415,7 @@ def test_get_trigger_timing(
         for idx, trig in enumerate(simulated_trigger_signal) if trig == 1
     ]
 
+
 def test_digitize_trigger(
         myphysiodata,
         myphysiodata_with_trigger,
@@ -427,8 +428,10 @@ def test_digitize_trigger(
         myphysiodata.get_trigger_timing()
     assert str(e_info.value) == "'trigger' is not in list"
 
-    # try with physiodata_with_trigger
-    assert myphysiodata_with_edf_trigger.digitize_trigger() == myphysiodata_with_trigger
+    # try with physiodata_with_trigger:
+    myphysiodata_with_edf_trigger.digitize_trigger()
+    assert myphysiodata_with_edf_trigger.get_trigger_physiosignal().signal == \
+           myphysiodata_with_trigger.get_trigger_physiosignal().signal
 
 
 def test_get_scanner_onset(
